@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-02 13:37:05
-@LastEditTime: 2022-06-14 15:49:18
+@LastEditTime: 2022-01-06 17:02:18
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -14,6 +14,7 @@ class IpInfoListHandler(ClientBaseHandler):
     """
     :description: 获取ip列表
     """
+    @filter_check_params("act_id")
     def get_async(self):
         """
         :description: 获取ip列表
@@ -24,9 +25,7 @@ class IpInfoListHandler(ClientBaseHandler):
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = self.get_act_id()
+        act_id = int(self.get_param("act_id", 0))
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 10))
-        page_list, total = IpBaseModel(context=self).get_ip_info_list(app_id, act_id, page_size, page_index, condition="is_release=1")
-        page_info = PageInfo(page_index, page_size, total, self.business_process_executed(page_list, ref_params={}))
-        return self.response_json_success(page_info)
+        self.response_json_success(IpBaseModel(context=self).get_ip_info_list(app_id, act_id, page_size, page_index, condition="is_release=1"))
