@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:49:46
-@LastEditTime: 2022-06-23 19:08:53
+@LastEditTime: 2022-05-19 09:33:57
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -10,7 +10,6 @@ from operator import truediv
 from seven_cloudapp_frame.libs.customize.seven_helper import SevenHelper
 from seven_cloudapp_frame.libs.customize.wechat_helper import WeChatPayRequest, WeChatPayReponse, WeChatRefundReponse
 from seven_cloudapp_frame.libs.customize.tiktok_helper import TikTokPayRequest, TikTokReponse
-from seven_cloudapp_frame.libs.customize.alipay_helper import AliPayRequest
 from seven_cloudapp_frame.models.shakeshop_base_model import *
 from seven_cloudapp_frame.models.price_base_model import *
 from seven_cloudapp_frame.models.asset_base_model import *
@@ -24,12 +23,12 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
     """
     :description: 创建微信预订单
     """
-    @filter_check_params("pay_order_no",check_user_code=True)
+    @filter_check_params("user_id,pay_order_no")
     def get_async(self):
         """
         :description: 创建微信预订单
         :param pay_order_no:支付单号
-        :param user_code:用户标识
+        :param user_id:用户标识
         :return: 请求接口获取客户端需要的支付密钥数据
         :last_editors: HuangJianYi
         """
@@ -65,7 +64,7 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
             # self.logging_link_info('小程序支付返回前端参数:' + str(invoke_result_data.data))
             ref_params = {}
             invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
-            return self.response_json_success(self.business_process_executed(invoke_result_data.data,ref_params={}))
+            return self.response_json_success(invoke_result_data.data)
         except Exception as ex:
             self.logging_link_error("【创建微信预订单异常】" + traceback.format_exc())
             return self.response_json_error("fail", "请重新支付")
@@ -211,12 +210,12 @@ class TiktokVoucherOrderHandler(ClientBaseHandler):
     """
     :description: 创建抖音预订单
     """
-    @filter_check_params("pay_order_no",check_user_code=True)
+    @filter_check_params("user_id,pay_order_no")
     def get_async(self):
         """
         :description: 创建抖音预订单
         :param pay_order_no:支付单号
-        :param user_code:用户标识
+        :param user_id:用户标识
         :return: 请求接口获取客户端需要的支付密钥数据
         :last_editors: HuangJianYi
         """
@@ -453,7 +452,7 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
                                 tiktok_goods_id_list = []
                                 if asset_type == 3:
                                     price_base_model = PriceBaseModel(context=self.context)
-                                    price_gear_dict_list,total = price_base_model.get_price_gear_list(user_info_dict["app_id"], user_info_dict["act_id"], 100, 0)
+                                    price_gear_dict_list = price_base_model.get_price_gear_list(user_info_dict["app_id"], user_info_dict["act_id"], 100, 0).data
                                     for price_gear_dict in price_gear_dict_list:
                                         tiktok_goods_id_list.append(price_gear_dict["goods_id"])
                                 else:
@@ -561,4 +560,4 @@ class ShakeshopNotifyHandler(FrameBaseHandler):
                 if is_add == True:
                     redis_init.lpush(pay_order_cache_key,item["sub_pay_order_no"])
                     redis_init.expire(pay_order_cache_key, 30 * 24 * 3600)
-        return pay_order_no_list,redis_init,pay_order_cache_key
+        return pay_order_no_list,redis_init,pay_order_cache_key
\ No newline at end of file
