@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-10 11:29:31
-@LastEditTime: 2022-07-07 17:55:26
+@LastEditTime: 2022-05-31 09:30:07
 @LastEditors: HuangJianYi
 @Description: 处理数据统计上报
 """
@@ -12,26 +12,27 @@ from seven_cloudapp_frame.models.stat_base_model import *
 
 class ShareReportHandler(ClientBaseHandler):
     """
-    :description: 处理分享统计上报
+    :description: 处理分享上报
     """
-    @filter_check_params("login_token", check_user_code=True)
+    @filter_check_params("act_id,tb_user_id,login_token")
     def get_async(self):
         """
-        :description: 处理分享统计上报
+        :description: 处理分享上报
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param user_code:用户标识
+        :param tb_user_id:用户标识
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = self.get_act_id()
+        act_id = int(self.get_param("act_id", 0))
         user_id = self.get_user_id()
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         stat_base_model = StatBaseModel(context=self)
+
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -47,34 +48,35 @@ class ShareReportHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success()
+        return self.response_json_success(invoke_result_data.data)
 
 
 class InviteReportHandler(ClientBaseHandler):
     """
-    :description: 处理邀请进入统计上报
+    :description: 处理邀请进入上报
     """
-    @filter_check_params("login_token", check_user_code=True)
+    @filter_check_params("act_id,tb_user_id,login_token")
     def get_async(self):
         """
-        :description: 处理邀请进入统计上报
+        :description: 处理邀请进入上报
         :param app_id:应用标识
         :param act_id:活动标识
         :param module_id:活动模块标识
-        :param user_code:用户标识
+        :param tb_user_id:用户标识
         :param invite_user_id:邀请人用户标识
         :param login_token:访问令牌
         :return: 
         :last_editors: HuangJianYi
         """
         app_id = self.get_source_app_id()
-        act_id = self.get_act_id()
+        act_id = int(self.get_param("act_id", 0))
         user_id = self.get_user_id()
         from_user_id = int(self.get_param("invite_user_id", 0))
         open_id = self.get_param("open_id")
         module_id = int(self.get_param("module_id", 0))
         login_token = self.get_param("login_token")
         stat_base_model = StatBaseModel(context=self)
+
         invoke_result_data = self.business_process_executing()
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
@@ -90,4 +92,4 @@ class InviteReportHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executed(invoke_result_data, ref_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        return self.response_json_success()
+        return self.response_json_success(invoke_result_data.data)
