@@ -2,18 +2,17 @@
 """
 @Author: HuangJianYi
 @Date: 2022-04-24 15:15:19
-@LastEditTime: 2022-07-07 16:47:46
+@LastEditTime: 2022-04-24 15:51:30
 @LastEditors: HuangJianYi
 @Description: 
 """
 
 from seven_framework.web_tornado.base_handler.base_api_handler import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
-from seven_cloudapp_frame.libs.customize.cryptography_helper import *
 from urllib.parse import parse_qs
 
 
-def filter_check_params(must_params=None, check_user_code=False):
+def filter_check_params(must_params=None):
     """
     :description: 参数过滤装饰器 仅限handler使用,
                   提供参数的检查及获取参数功能
@@ -23,7 +22,6 @@ def filter_check_params(must_params=None, check_user_code=False):
                   参数获取方法:
                   self.request_params[param_key]
     :param must_params: 必须传递的参数集合
-    :param check_user_code: 是否校验用户标识必传
     :last_editors: HuangJianYi
     """
     def check_params(handler):
@@ -39,11 +37,8 @@ def filter_check_params(must_params=None, check_user_code=False):
             if finally_must_params:
                 for must_param in must_array:
                     if not must_param in self.request_params or self.request_params[must_param] == "":
-                        self.response_json_error("param_error", f"参数错误,缺少必传参数{must_param}")
+                        self.response_json_error("param_error", "参数错误,缺少必传参数")
                         return
-            if check_user_code == True and not self.get_user_id():
-                self.response_json_error("param_error", f"参数错误,缺少必传参数user_code")
-                return
 
             return handler(self, **args)
 
@@ -89,7 +84,7 @@ def filter_check_head_sign(is_check=True, no_check_params=None):
                             return self.response_json_error("signature_md5", "缺少参数signature_md5")
                         # 验证头部签名是否成功
                         client_head_dict = dict([(k, v[0]) for k, v in parse_qs(clientheaderinfo_string, True).items() if not k in no_check_array])
-                        head_signature_md5 = CryptographyHelper.signature_md5(client_head_dict, encrypt_key)
+                        head_signature_md5 = self.get_signature_md5(client_head_dict, encrypt_key)
                         signature_md5 = device_info_dict["signature_md5"].lower()
                         if signature_md5 != head_signature_md5:
                             return self.response_json_error("signature_fail", "头部签名验证失败")
@@ -141,7 +136,7 @@ def filter_check_params_sign(is_check=True, no_check_params=None):
                         pass
                     if not request_param_dict.__contains__("param_signature_md5"):
                         return self.response_json_error("signature_fail", "缺少参数param_signature_md5")
-                    check_request_signature_md5 = CryptographyHelper.signature_md5(request_param_dict, encrypt_key)
+                    check_request_signature_md5 = self.get_signature_md5(request_param_dict, encrypt_key)
                     param_signature_md5 = request_param_dict["param_signature_md5"].lower()
                     if check_request_signature_md5 != param_signature_md5:
                         return self.response_json_error("signature_fail", "参数签名验证失败")
