@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-15 11:30:45
-@LastEditTime: 2022-07-07 18:23:12
+@LastEditTime: 2022-06-08 14:44:37
 @LastEditors: HuangJianYi
 @Description: 公共handler模块
 """
@@ -20,12 +20,14 @@ from seven_framework.redis import *
 from seven_framework.web_tornado.base_handler.base_api_handler import *
 from seven_cloudapp_frame.libs.customize.seven_helper import *
 from seven_cloudapp_frame.libs.customize.cryptography_helper import *
-from seven_cloudapp_frame.libs.customize.riskmanage_helper import *
+from seven_cloudapp_frame.libs.customize.attack_helper import *
 from seven_cloudapp_frame.models.seven_model import *
 from seven_cloudapp_frame.models.user_base_model import *
 from seven_cloudapp_frame.models.db_models.app.app_info_model import *
 from seven_cloudapp_frame.models.db_models.act.act_info_model import *
 from seven_cloudapp_frame.models.db_models.operation.operation_log_model import *
+from seven_cloudapp_frame.models.mp_base_model import MPBaseModel
+from seven_cloudapp_frame.models.app_base_model import AppBaseModel
 from seven_cloudapp_frame.handlers.filter_base import *
 
 
@@ -78,16 +80,6 @@ class FrameBaseHandler(BaseApiHandler):
     def check_xsrf_cookie(self):
         return
 
-    def set_default_headers(self):
-        allow_origin_list = config.get_value("allow_origin_list")
-        origin = self.request.headers.get("Origin")
-        if origin in allow_origin_list:
-            self.set_header("Access-Control-Allow-Origin", origin)
-
-        self.set_header("Access-Control-Allow-Headers", "Origin,X-Requested-With,Content-Type,Accept,User-Token,Manage-ProductID,Manage-PageID,PYCKET_ID")
-        self.set_header("Access-Control-Allow-Methods", "POST,GET,OPTIONS,PUT,DELETE")
-        self.set_header("Access-Control-Allow-Credentials", "true")
-
     def json_dumps(self, rep_dic):
         """
         :description: 将字典转化为字符串
@@ -124,11 +116,11 @@ class FrameBaseHandler(BaseApiHandler):
             param_ret = self.get_argument(param_name, default, strip=strip)
         if param_ret == "" or param_ret == "undefined":
             param_ret = default
-        param_ret = RiskManageHelper.filter_routine_key(param_ret)
+        param_ret = AttackHelper.filter_routine_key(param_ret)
         if filter_sql == True:
-            param_ret = RiskManageHelper.filter_sql(param_ret)
+            param_ret = AttackHelper.filter_sql(param_ret)
         if filter_special_key == True:
-            param_ret = RiskManageHelper.filter_special_key(param_ret)
+            param_ret = AttackHelper.filter_special_key(param_ret)
         return param_ret
 
     def get_param_int(self, param_name, default=0, strip=True, filter_sql=False, filter_special_key=False):
@@ -153,8 +145,8 @@ class FrameBaseHandler(BaseApiHandler):
         :Description: 校验是否加密
         :last_editors: HuangJianYi
         """
-        client_encrypt_type = config.get_value("client_encrypt_type", 0)  #客户端加密类型 0-无，1-aes加密
-        server_encrypt_type = config.get_value("server_encrypt_type", 0)  #千牛端或后台加密类型 0-无，1-aes加密
+        client_encrypt_type = config.get_value("client_encrypt_type", 0)  #客户端加密类型 0-无，1-aes加密，2-md5加密
+        server_encrypt_type = config.get_value("server_encrypt_type", 0)  #千牛端或后台加密类型 0-无，1-aes加密，2-md5加密
         is_encrypt = False if hasattr(self, "is_encrypt") and self.is_encrypt == False else True
         if is_encrypt == True and ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
             return True
@@ -180,7 +172,7 @@ class FrameBaseHandler(BaseApiHandler):
             if not app_id:
                 app_id = config.get_value("app_id")
             password = str(encrypt_key).replace("1", "l")
-            if "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
+            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
                 try:
                     json_params = json.loads(self.request.body)
                     if json_params:
@@ -225,7 +217,7 @@ class FrameBaseHandler(BaseApiHandler):
                     return invoke_result_data
 
         else:
-            if "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
+            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
                 try:
                     json_params = json.loads(self.request.body)
                     if json_params:
@@ -364,6 +356,43 @@ class FrameBaseHandler(BaseApiHandler):
         """
         return SevenHelper.create_order_id(ran)
 
+    def get_signature_md5(self, request_param_dict, encrypt_key=""):
+        """
+        :description: 参数按照加密规则进行MD5加密
+        :description: 签名规则 signature_md5= ((参数1=参数1值&参数2=参数2值&signature_stamp={signature_stamp}))+密钥)进行Md5加密转小写，参数顺序按照字母表的顺序排列
+        :param request_param_dict: 请求参数字典
+        :param encrypt_key: 接口密钥
+        :return: 加密后的md5值，由于跟客户端传来的加密参数进行校验
+        """
+        request_sign_params = {}
+        for k, v in request_param_dict.items():
+            if k == "param_signature_md5":
+                continue
+            if k == "signature_md5":
+                continue
+            request_sign_params[k] = str(v).replace(" ", "_seven_").replace("(", "_seven1_").replace(")", "_seven2_")
+        request_params_sorted = sorted(request_sign_params.items(), key=lambda e: e[0], reverse=False)
+        request_message = "&".join(k + "=" + CodingHelper.url_encode(v) for k, v in request_params_sorted)
+        request_message = request_message.replace("_seven_", "%20").replace("_seven1_", "(").replace("_seven2_", ")").replace("%27", "'")
+        # MD5摘要
+        request_encrypt = hashlib.md5()
+        request_encrypt.update((request_message + str(encrypt_key)).encode("utf-8"))
+        check_request_signature_md5 = request_encrypt.hexdigest().lower()
+        return check_request_signature_md5
+
+    def add_request_user(self, app_id, object_id):
+        """
+        :description: 每分钟流量UV计数,用于登录接口限制登录
+        :param app_id: 应用标识
+        :param object_id: 用户唯一标识
+        :return:
+        :last_editors: HuangJianYi
+        """
+        redis_init = SevenHelper.redis_init()
+        cache_key = f"request_user_list_{app_id}:{str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M'))}"
+        redis_init.sadd(cache_key, object_id)
+        redis_init.expire(cache_key, 3600)
+
     def get_app_key_secret(self):
         """
         :description: 获取app_key和app_secret
@@ -375,6 +404,23 @@ class FrameBaseHandler(BaseApiHandler):
         app_secret = config.get_value("app_secret")
         return app_key, app_secret
 
+    def set_default_headers(self):
+        """
+        :description: 设置默认头部，用于跨域请求
+        :return
+        :last_editors: HuangJianYi
+        """
+        allow_origin_list = config.get_value("allow_origin_list")
+        if not allow_origin_list:
+            return
+        origin = self.request.headers.get("Origin")
+        if origin in allow_origin_list:
+            self.set_header("Access-Control-Allow-Origin", origin)
+
+        self.set_header("Access-Control-Allow-Headers", "Origin,X-Requested-With,Content-Type,Accept,User-Token,Manage-ProductID,Manage-PageID,PYCKET_ID")
+        self.set_header("Access-Control-Allow-Methods", "POST,GET,OPTIONS")
+        self.set_header("Access-Control-Allow-Credentials", "true")
+
     def get_user_nick(self):
         """
         :description: 获取用户昵称
@@ -403,42 +449,36 @@ class FrameBaseHandler(BaseApiHandler):
 
     def get_user_id(self):
         """
-        :description: 获取user_id,后续新项目统一使用user_code,tb_user_id和user_id只做兼容旧项目使用保留
+        :description: 获取user_id
         :param self
         :return str
         :last_editors: HuangJianYi
         """
-        user_id = self.get_param_int("user_code")
+        user_id = self.get_param_int("tb_user_id")
         if user_id == 0:
-            user_id = self.get_param_int("tb_user_id")
-            if user_id == 0:
-                user_id = self.get_param_int("user_id")
+            user_id = self.get_param_int("user_id")
         return user_id
 
     def get_source_app_id(self):
         """
-        :description: 获取source_app_id(客户端client使用)
+        :description: 获取source_app_id(客户端使用)
         :return str
         :last_editors: HuangJianYi
         """
         #当有参数app_id时，优先取app_id，然后在是source_app_id
-        source_app_id = self.get_param("app_id")
-        if source_app_id:
+        if self.get_param("app_id"):
+            source_app_id = self.get_param("app_id")
             return source_app_id
         source_app_id = self.get_param("source_app_id")
-        plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音
-        if plat_type == 1:
-            #淘宝小程序 在IDE上返回前端模板id，无论哪个环境；在千牛端上返回正确的小程序id
-            if source_app_id == config.get_value("client_template_id") or source_app_id == "":
-                test_config = config.get_value("test_config",{})
-                source_app_id = test_config.get("source_app_id","")
-        else:
-            source_app_id = config.get_value("app_id")
+        #淘宝小程序 在IDE上返回前端模板id，无论哪个环境；在千牛端上返回正确的小程序id
+        if source_app_id == config.get_value("client_template_id") or source_app_id == "":
+            test_config = config.get_value("test_config",{})
+            source_app_id = test_config.get("source_app_id","")
         return source_app_id
 
     def get_app_id(self):
         """
-        :description: 获取app_id(后台端server使用)
+        :description: 获取app_id(后台使用)
         :param self
         :return str
         :last_editors: HuangJianYi
@@ -446,16 +486,13 @@ class FrameBaseHandler(BaseApiHandler):
         app_id = self.get_param("app_id")
         if app_id == "":
             plat_type = config.get_value("plat_type", 1)  # 平台类型 1淘宝2微信3抖音
-            if plat_type == 1:
-                user_nick = self.get_user_nick()
-                if user_nick:
-                    store_user_nick = user_nick.split(':')[0]
-                    if store_user_nick:
-                        app_info_dict = AppInfoModel(context=self).get_cache_dict(where="store_user_nick=%s", limit="0,1", field="app_id", params=store_user_nick)
-                        if app_info_dict:
-                            app_id = app_info_dict["app_id"]
-            else:
-                app_id = config.get_value("app_id")
+            user_nick = self.get_user_nick()
+            if user_nick and plat_type == 1:
+                store_user_nick = user_nick.split(':')[0]
+                if store_user_nick:
+                    app_info_dict = AppInfoModel(context=self).get_cache_dict(where="store_user_nick=%s", limit="0,1", field="app_id", params=store_user_nick)
+                    if app_info_dict:
+                        app_id = app_info_dict["app_id"]
         return app_id
 
     def get_access_token(self):
@@ -473,18 +510,6 @@ class FrameBaseHandler(BaseApiHandler):
                 access_token = test_config.get("access_token","")
         return access_token
 
-    def get_act_id(self):
-        """
-        :description: 获取act_id 如果没传取配置文件的值，配置文件没配置设置默认值1
-        :return int
-        :last_editors: HuangJianYi
-        """
-        config_act_id = config.get_value("act_id",1)
-        act_id = self.get_param_int("act_id",0)
-        if act_id <= 0:
-            act_id = config_act_id
-        return act_id
-
     def create_operation_log(self, operation_type=1, model_name="", handler_name="", old_detail=None, update_detail=None, operate_user_id="", operate_user_name=""):
         """
         :description: 创建操作日志
@@ -502,7 +527,7 @@ class FrameBaseHandler(BaseApiHandler):
         operation_log_model = OperationLogModel(context=self)
 
         operation_log.app_id = ""
-        operation_log.act_id = self.get_act_id()
+        operation_log.act_id = int(self.get_param("act_id", 0))
         operation_log.open_id = self.get_open_id()
         operation_log.user_nick = self.get_user_nick()
         operation_log.request_params = self.request_params
@@ -529,6 +554,35 @@ class FrameBaseHandler(BaseApiHandler):
 
         operation_log_model.add_entity(operation_log)
 
+    def check_request_user(self, app_id, current_limit_count, current_limit_minute=1):
+        """
+        :description: 每分钟流量UV校验
+        :param app_id: 应用标识
+        :param current_limit_count: 流量限制数
+        :param current_limit_minute: 流量限制时间，默认1分钟
+        :return: True代表满足限制条件进行拦截
+        :last_editors: HuangJianYi
+        """
+        if current_limit_count == 0:
+            return False
+        redis_init = SevenHelper.redis_init()
+        if current_limit_minute == 1:
+            cache_key = f"request_user_list_{app_id}:{str(SevenHelper.get_now_int(fmt='%Y%m%d%H%M'))}"
+        else:
+            key_list = []
+            for i in range(current_limit_minute):
+                now_minute_int = int((datetime.datetime.now() + datetime.timedelta(minutes=-i)).strftime('%Y%m%d%H%M'))
+                key = f"request_user_list_{app_id}:{str(now_minute_int)}"
+                key_list.append(key)
+            cache_key = f"request_user_list_{app_id}"
+            redis_init.sinterstore(cache_key, key_list)
+            redis_init.expire(cache_key, 3600)
+
+        if int(redis_init.scard(cache_key)) >= current_limit_count:
+            return True
+        else:
+            return False
+
     def check_continue_request(self, handler_name, app_id, object_id, expire=100):
         """
         :description: 一个用户同一handler频繁请求校验，只对同用户同接口同请求参数进行限制
@@ -541,11 +595,29 @@ class FrameBaseHandler(BaseApiHandler):
         """
         result = False, ""
         if object_id and handler_name and app_id:
-            sign = CryptographyHelper.signature_md5(self.request_params)
+            sign = self.get_signature_md5(self.request_params)
             if SevenHelper.is_continue_request(f"continue_request:{handler_name}_{app_id}_{object_id}_{sign}", expire) == True:
                 result = True, f"操作太频繁,请{expire}毫秒后再试"
         return result
 
+    def check_handler_power(self):
+        """
+        :description: 校验是否有权限访问接口
+        :return:True有False没有
+        :last_editors: HuangJianYi
+        """
+        result = True
+        if self.request_params and self.request_params.get("app_id",""):
+            server_power_config = config.get_value("server_power_config", {})
+            power_codes = server_power_config.get(self.__class__.__name__,"")
+            if power_codes:
+                app_base_model = AppBaseModel(context=self.context)
+                app_info_dict = app_base_model.get_app_info_dict(self.request_params.get("app_id",""))
+                if app_info_dict:
+                    mp_base_model = MPBaseModel(context=self.context)
+                    result = mp_base_model.check_high_power(store_user_nick=app_info_dict["store_user_nick"], project_code=app_info_dict["project_code"], key_names=power_codes)
+        return result
+
     def business_process_executing(self):
         """
         :description: 执行前事件
@@ -578,35 +650,42 @@ class ClientBaseHandler(FrameBaseHandler):
         """
         if self.__class__.__name__ == "IndexHandler":
             return
+
+        #获取并转换请求参数
+        invoke_result_data = self._convert_request_params()
+        if invoke_result_data.success == False:
+            self.request_code = UUIDHelper.get_uuid()
+            self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
+            self.finish()
+            return
+
         try:
-            #获取并转换请求参数
-            invoke_result_data = self._convert_request_params()
-            if invoke_result_data.success == False:
-                self.request_code = UUIDHelper.get_uuid()
-                self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-                self.finish()
-                return
             # 标记日志请求关联
             dict_param = self.get_http_log_extra_dict()
             self._build_http_log(dict_param)
-            # 是否加密模式
-            is_api_encrypt = self.is_api_encrypt()
+
+            # 获取设备信息
+            self.device_info_dict = self.get_device_info_dict()
+
             # 记录请求参数明文
-            if config.get_value("log_plain", True) == True and is_api_encrypt == True:
+            if config.get_value("log_plain", True) == True and self.is_api_encrypt() == True:
                 self.logging_link_info(f"plain_request_params:{self.json_dumps(self.request_params)}")
-            # 验证超时 10秒过期
-            if is_api_encrypt == True:
+
+            # 防攻击校验
+            is_attack_request, error_message = AttackHelper.check_attack_request()
+            if is_attack_request:
+                self.response_json_error("error", error_message)
+                self.finish()
+                return
+
+            # 验证超时 10分钟过期
+            if self.is_api_encrypt() == True:
                 now_time = TimeHelper.get_now_timestamp(True)
-                if self.request_params.__contains__("timestamp") and (now_time - int(self.request_params["timestamp"]) > int(1000 * 10)):
+                if self.request_params.__contains__("timestamp") and (now_time - int(self.request_params["timestamp"]) > int(1000 * 60 * 10)):
                     self.response_json_error("timestamp", "超时操作")
                     self.finish()
                     return
-            # 防攻击校验
-            invoke_result_data = RiskManageHelper.check_attack_request()
-            if invoke_result_data.success == False:
-                self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-                self.finish()
-                return
+
             # 频繁请求校验
             if dict_param["open_id"] and "/client/" in self.request.uri:
                 is_continue_request, error_message = self.check_continue_request(self.__class__.__name__, dict_param["app_id"], dict_param["open_id"])
@@ -616,20 +695,49 @@ class ClientBaseHandler(FrameBaseHandler):
                     return
 
                 #每分钟流量UV计数,用于登录接口限制登录
-                RiskManageHelper.add_current_limit_count(str(dict_param["app_id"]), str(dict_param["open_id"]))
+                self.add_request_user(str(dict_param["app_id"]), str(dict_param["open_id"]))
+
             # 校验是否有权限，有才能访问接口
-            if not RiskManageHelper.check_handler_power(self.request_params, self.request.uri, self.__class__.__name__):
+            if not self.check_handler_power():
                 self.response_json_error("no_power", "没有权限操作")
                 self.finish()
                 return
-            # 获取设备信息
-            self.device_info_dict = self.get_device_info_dict()
-
+                
         except Exception as ex:
             if not hasattr(self, "request_code"):
                 self.request_code = UUIDHelper.get_uuid()
             self.logging_link_error("【客户端handler基类】" + traceback.format_exc())
 
+    def get_online_url(self, act_id, app_id, module_id=0):
+        """
+        :description: 获取online_url
+        :param act_id:活动标识
+        :param app_id:应用标识
+        :param module_id:模块标识
+        :param page:跳转的首页地址pages/index/index
+        :return str
+        :last_editors: HuangJianYi
+        """
+        page_index = ""
+        page = config.get_value("page_index")
+        if page:
+            page_index = "&page=" + CodingHelper.url_encode(page)
+        query = CodingHelper.url_encode(f"actid={act_id}")
+        if module_id > 0:
+            query = CodingHelper.url_encode(f"actid={act_id}&module_id={module_id}")
+        online_url = f"https://m.duanqu.com/?_ariver_appid={app_id}{page_index}&query={query}"
+        return online_url
+
+    def get_live_url(self, app_id):
+        """
+        :description: 获取live_url
+        :param app_id:应用标识
+        :return str
+        :last_editors: HuangJianYi
+        """
+        live_url = f"https://market.m.taobao.com/app/taefed/shopping-delivery-wapp/index.html#/putin?mainKey=form&appId={app_id}"
+        return live_url
+
     def get_device_info_dict(self):
         """
         :description: 获取头部参数字典
