@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-01-14 10:44:07
-@LastEditTime: 2022-01-10 13:54:31
+@LastEditTime: 2022-04-26 09:05:17
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -204,7 +204,9 @@ class TikTokHelper:
                 invoke_result_data.error_code = response_data["err_no"]
                 invoke_result_data.error_message = response_data["err_tips"]
                 return invoke_result_data
-            return response_data
+            else:
+                invoke_result_data.data = response_data.content
+            return invoke_result_data
         except Exception as ex:
             self.logger_error.error("【create_qr_code】" + traceback.format_exc() + ":" + str(response.text))
             invoke_result_data.success = False
