@@ -80,13 +80,13 @@ class WeChatHelper:
             return invoke_result_data
 
     @classmethod
-    def get_access_token(self, grant_type="client_credential",app_id="", app_secret="",is_del=False):
+    def get_access_token(self, app_id="", app_secret="", is_del=False, grant_type="client_credential"):
         """
         :description:access_token 是小程序的全局唯一调用凭据，开发者调用小程序支付时需要使用 access_token。access_token 的有效期为 2 个小时，需要定时刷新 access_token，重复获取会导致之前一次获取的 access_token 的有效期缩短为 5 分钟。建议开发者使用中控服务器统一获取和刷新 access_token，其他业务逻辑服务器所使用的 access_token 均来自于该中控服务器，不应该各自去刷新，否则容易造成冲突，导致 access_token 覆盖而影响业务；
-        :param grant_type: 获取access_token 时值为 client_credential
         :param app_id:app_id
         :param app_secret:app_secret
         :param is_del:是否删除redis里的access_token
+        :param grant_type: 获取access_token 时值为 client_credential
         :return: 
         :last_editors: HuangJianYi
         """
@@ -201,7 +201,7 @@ class WeChatHelper:
                 invoke_result_data = self.get_access_token(app_id, app_secret)
             else:
                 invoke_result_data = self.get_access_token(app_id, app_secret, True)
-                
+
             if invoke_result_data.success == True:
                 break
         if invoke_result_data.success == False:
@@ -249,7 +249,7 @@ class WeChatHelper:
                 invoke_result_data = self.get_access_token(app_id, app_secret)
             else:
                 invoke_result_data = self.get_access_token(app_id, app_secret, True)
-                
+
             if invoke_result_data.success == True:
                 break
         if invoke_result_data.success == False:
