@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2022-02-10 11:26:58
+@LastEditTime: 2022-04-29 16:24:33
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -26,11 +26,13 @@ class AssetConsoleModel():
         :return: 
         :last_editors: HuangJianYi
         """
-        sub_table_count = config.get_value("asset_sub_table_count", 0)
-        if sub_table_count == 0:
+        sub_table_config_list = config.get_value("sub_table_config_list", {})
+        sub_table_config = sub_table_config_list.get("asset_log_tb", {"sub_count": 0, "sub_ways": 0})
+        sub_count = sub_table_config.get("sub_count", 0)
+        if sub_count == 0:
             self._start_process_user_asset_warn(None, mod_count)
         else:
-            for i in range(sub_table_count):
+            for i in range(sub_count):
                 self._start_process_user_asset_warn(str(i), mod_count)
 
         for i in range(mod_count):
