@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-20 10:09:52
-@LastEditTime: 2021-07-29 18:28:39
+@LastEditTime: 2022-03-08 18:55:48
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -49,7 +49,9 @@ class AppInfo:
         self.instance_date = "1900-01-01 00:00:00"  # 实例化时间
         self.is_setting = 0  # 是否完成数据配置：0-未完成，1-已配置
         self.expiration_date = "1900-01-01 00:00:00"  # 过期时间
+        self.project_code = ""  # 项目编码
         self.modify_date = "1900-01-01 00:00:00"  # 更新时间
+        self.is_gm = 0  # 是否开启gm权限：0-否，1-是
         self.current_limit_count = 0  # 限流数量
         self.i1 = 0  # i1
         self.i2 = 0  # i2
@@ -62,7 +64,7 @@ class AppInfo:
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'store_name', 'store_user_nick', 'store_id', 'store_icon', 'seller_id', 'app_id', 'app_name', 'app_icon', 'app_url', 'app_ver', 'app_key', 'access_token', 'preview_url', 'app_desc', 'template_id', 'template_ver', 'clients', 'app_telephone', 'is_instance', 'instance_date', 'is_setting', 'expiration_date', 'modify_date', 'current_limit_count', 'i1', 'i2', 'i3', 'i4', 's1', 's2', 's3', 's4']
+        return ['id', 'store_name', 'store_user_nick', 'store_id', 'store_icon', 'seller_id', 'app_id', 'app_name', 'app_icon', 'app_url', 'app_ver', 'app_key', 'access_token', 'preview_url', 'app_desc', 'template_id', 'template_ver', 'clients', 'app_telephone', 'is_instance', 'instance_date', 'is_setting', 'expiration_date', 'project_code', 'modify_date', 'is_gm', 'current_limit_count', 'i1', 'i2', 'i3', 'i4', 's1', 's2', 's3', 's4']
 
     @classmethod
     def get_primary_key(self):
