@@ -34,13 +34,17 @@ class UserAccount:
         self.user_nick_encrypt = ""  # 昵称加密值
         self.avatar = ""  # 头像
         self.user_state = 0  # 用户状态（0-正常，1-黑名单）
+        self.full_name = ""  # 姓名
+        self.telephone = ""  #电话号码
+        self.certificate_type = 1  #证件类型(1身份证2军官证)
+        self.certificate_no = "" #证件号码
         self.relieve_date = "1900-01-01 00:00:00"  # 解禁时间
         self.create_date = "1900-01-01 00:00:00"  # 创建时间
         self.modify_date = "1900-01-01 00:00:00"  # 修改时间
 
     @classmethod
     def get_field_list(self):
-        return ['id', 'union_id', 'open_id', 'user_nick', 'user_nick_encrypt', 'avatar', 'user_state', 'relieve_date', 'create_date', 'modify_date']
+        return ['id', 'union_id', 'open_id', 'user_nick', 'user_nick_encrypt', 'avatar', 'user_state','full_name','telephone','certificate_type','certificate_no', 'relieve_date', 'create_date', 'modify_date']
 
     @classmethod
     def get_primary_key(self):
