@@ -11,8 +11,10 @@ class LaunchBaseModel():
     """
     :description: 淘宝商品投放业务模型
     """
-    def __init__(self, context):
+    def __init__(self, context=None, logging_error=None, logging_info=None):
         self.context = context
+        self.logging_link_error = logging_error
+        self.logging_link_info = logging_info
 
     def add_launch_goods(self, app_id, act_id, goods_id, old_goods_id, source_types):
         """
