@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-04 13:41:15
-@LastEditTime: 2022-07-01 18:50:43
+@LastEditTime: 2022-05-23 11:45:24
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -22,11 +22,10 @@ class PrizeBaseModel():
         self.logging_link_error = logging_error
         self.logging_link_info = logging_info
 
-    def _delete_act_prize_dependency_key(self, act_id, model_id, prize_id, delay_delete_time=0.01):
+    def _delete_act_prize_dependency_key(self, act_id, prize_id, delay_delete_time=0.01):
         """
         :description: 删除活动奖品依赖建
         :param act_id: 活动标识
-        :param model_id: 模块标识
         :param prize_id: 奖品标识
         :param delay_delete_time: 延迟删除时间，传0则不进行延迟
         :return: 
@@ -36,10 +35,7 @@ class PrizeBaseModel():
         if prize_id:
             dependency_key_list.append(f"act_prize:prizeid_{prize_id}")
         if act_id:
-            if model_id:
-                dependency_key_list.append(f"act_prize_list:actid_{act_id}_moduleid_{model_id}")
-            else:
-                dependency_key_list.append(f"act_prize_list:actid_{act_id}")
+            dependency_key_list.append(f"act_prize_list:actid_{act_id}")
         ActPrizeModel().delete_dependency_key(dependency_key_list,delay_delete_time)
 
 
@@ -93,7 +89,7 @@ class PrizeBaseModel():
         if is_del !=-1:
             where += " and is_del=%s"
             params_list.append(is_del)
-        if module_id:
+        if module_id !=0:
             where += " and module_id=%s"
             params_list.append(module_id)
         if prize_name:
@@ -101,10 +97,7 @@ class PrizeBaseModel():
             params_list.append(prize_name)
         act_prize_model = ActPrizeModel(context=self.context)
         if is_cache:
-            dependency_key = f"act_prize_list:actid_{act_id}"
-            if module_id:
-                dependency_key += f"_moduleid_{module_id}"
-            page_list, total = act_prize_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,dependency_key=dependency_key)
+            page_list, total = act_prize_model.get_cache_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list,dependency_key=f"act_prize_list:actid_{act_id}")
         else:
             page_list, total = act_prize_model.get_dict_page_list(field=field, page_index=page_index, page_size=page_size, where=where, group_by="", order_by=order_by, params=params_list)
         return page_list, total
@@ -238,7 +231,7 @@ class PrizeBaseModel():
         result["new"] = act_prize
         result["old"] = old_act_prize
         invoke_result_data.data = result
-        self._delete_act_prize_dependency_key(act_id,module_id,act_prize.id)
+        self._delete_act_prize_dependency_key(act_id,act_prize.id)
         return invoke_result_data
 
     def save_tao_coupon(self,app_id,act_id,prize_id,coupon_type,right_ename,pool_id,coupon_start_date,coupon_end_date,coupon_url,coupon_price,use_sill_price):
@@ -304,7 +297,7 @@ class PrizeBaseModel():
         is_release = 0 if is_del == 1 else 1
         modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = act_prize_model.update_table("is_del=%s,is_release=%s,modify_date=%s", "id=%s", [is_del, is_release, modify_date, prize_id])
-        self._delete_act_prize_dependency_key(act_prize_dict["act_id"],act_prize_dict["module_id"],prize_id)
+        self._delete_act_prize_dependency_key(act_prize_dict["act_id"],prize_id)
         return invoke_result_data
 
     def release_act_prize(self,app_id,prize_id,is_release):
@@ -326,5 +319,5 @@ class PrizeBaseModel():
             return invoke_result_data
         modify_date = SevenHelper.get_now_datetime()
         invoke_result_data.success = act_prize_model.update_table("modify_date=%s,is_release=%s", "id=%s", [modify_date, is_release, prize_id])
-        self._delete_act_prize_dependency_key(act_prize_dict["act_id"],act_prize_dict["module_id"],prize_id)
+        self._delete_act_prize_dependency_key(act_prize_dict["act_id"],prize_id)
         return invoke_result_data
